# Rust编程指南

做任何事情，初心和目标很重要，过程也很重要，那么这里我们就来谈谈这些，关于书，关于Rust在国内的发展。*强烈建议读者大大们不要跳过下面的内容，对于你对这本书的理解和定位会很有帮助*。

## 关于本书

- 官方书名： Rust编程指南(The Way To Rust)
- 官方网址： https://wayto.rs
- 修订时间： 尚未发行
- Rust版本：Rust edition 2021

#### 书本简介
`Rust编程指南`是一本涵盖了从入门到精通各个阶段的Rust书籍，书本的章节和内容组织经过深思熟虑的设计，以符合中国用户的编程使用习惯，目的是尽量对新手更友好，同时也更方便老手的后期检索查询。

使用Rust的用户往往都对性能非常感兴趣，因此本书对于性能优化方面也是分散落入各个章节中，同时还有一个专门的[性能优化](./performance/intro.md)专题，来帮助用户系统的认识如何优化Rust项目的性能。

针对不同的使用场景，我们也给出了多种模版代码，方便用户直接复制粘贴到代码中，例如读取文件、http请求等，无需再去网上搜索。

Rust的外部库层次不齐，针对这一点，我们根据功能分类推荐了相应的高质量开源库，同时提供了基础的使用帮助。

**在学完这本书后，你也会随之完成数个小型项目**，例如其中一些是：
- Mandelbrot集合渲染
- 类Grep命令
- CPU模拟器
- 小型数据库
- 小型Redis
- HTTP等网络请求客户端
- 小型操作系统内核

从上面的列表可以看出，学完本书，不仅会教会你Rust语言，还能学到系统编程和底层编程, 尽情享受奇妙的编程之旅吧。

#### 创作初心

还有很多，就不一一列举，等待大家自己去探索挖掘。 总之在写作过程中我们始终铭记初心：**为用户打造一本真正的Rust中文好书。 新手用来入门，老手用来提高，高手能用来提升生产力**。

#### 目标读者

目标读者大致能落在以下三个范畴内
1. 有其它语言编程基础，无Rust编程语言经验的爱好者
2. 已经熟悉Rust想要更进一步的中级Rust程序员
3. 想要随时检索一些Rust知识和代码，对生产力有要求的Rust开发者

#### 书中的一些标识说明
| Ferris                                                                                                           | 意义                                          |
|------------------------------------------------------------------------------------------------------------------|--------------------------------------------------|
| <img src="img/ferris/does_not_compile.svg" class="ferris-explain" alt="Ferris with a question mark"/>            | 这些代码不能编译！                     |
| <img src="img/ferris/panics.svg" class="ferris-explain" alt="Ferris throwing up their hands"/>                   | 这些代码会 panic！                                |
| <img src="img/ferris/not_desired_behavior.svg" class="ferris-explain" alt="Ferris with one claw up, shrugging"/> | 这些代码没有产生期望的行为。 |

在大部分情况，我们会指引你将任何不能编译的代码纠正为正确版本。

## Rust社区

与国外的Rust发展如火如荼相比，国内的近况不是特别理想。

导致目前这种状况的原因，我个人认为有以下几点原因：
1. 上手难度大，学习曲线陡峭
2. 中文资料少，英文资料难学(基于原因1)
3. 没有体系化的学习路线，新人往往扫完一遍入门书籍，就不知道何去何从

因此我联合几个朋友一起创建了RustCm社区(Rust Cn Members), `cm = cn members`，顾名思义这个社区最核心的是`中国成员`，只有有了这样一群真心喜欢Rust的成员，才能形成真正有力、可持续发展的社区。

官网网址:
- https://rust.cm
- https://rustcm.com

后者为了未来国内备案使用

